i128

Function i128 

pub(in num) const unsafe fn i128(
    n: i128,
) -> i128
🔬This is a nightly-only experimental API. (num_internals)
Returns the integer square root of any nonnegative i128 input.

Safety

This results in undefined behavior when the input is negative.