i16

Function i16 

pub(in num) const unsafe fn i16(
    n: i16,
) -> i16
🔬This is a nightly-only experimental API. (num_internals)
Returns the integer square root of any nonnegative i16 input.

Safety

This results in undefined behavior when the input is negative.