i32

Function i32 

pub(in num) const unsafe fn i32(
    n: i32,
) -> i32
🔬This is a nightly-only experimental API. (num_internals)
Returns the integer square root of any nonnegative i32 input.

Safety

This results in undefined behavior when the input is negative.