i64

Function i64 

pub(in num) const unsafe fn i64(
    n: i64,
) -> i64
🔬This is a nightly-only experimental API. (num_internals)
Returns the integer square root of any nonnegative i64 input.

Safety

This results in undefined behavior when the input is negative.