i8

Function i8 

pub(in num) const unsafe fn i8(
    n: i8,
) -> i8
🔬This is a nightly-only experimental API. (num_internals)
Returns the integer square root of any nonnegative i8 input.

Safety

This results in undefined behavior when the input is negative.